@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.17   2016/09/28
+ * Version: 0.2   2016/10/05
  */
 
 #include <linux/version.h>
@@ -71,6 +71,7 @@ static _Bool cs_policy_loader_exists(void)
 {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 28)
 	struct path path;
+
 	if (!cs_loader)
 		cs_loader = CONFIG_CAITSITH_POLICY_LOADER;
 	if (kern_path(cs_loader, LOOKUP_FOLLOW, &path) == 0) {
@@ -79,6 +80,7 @@ static _Bool cs_policy_loader_exists(void)
 	}
 #else
 	struct nameidata nd;
+
 	if (!cs_loader)
 		cs_loader = CONFIG_CAITSITH_POLICY_LOADER;
 	if (path_lookup(cs_loader, LOOKUP_FOLLOW, &nd) == 0) {
@@ -86,8 +88,8 @@ static _Bool cs_policy_loader_exists(void)
 		return 1;
 	}
 #endif
-	printk(KERN_INFO "Not activating Mandatory Access Control "
-	       "as %s does not exist.\n", cs_loader);
+	printk(KERN_INFO "Not activating CaitSith as %s does not exist.\n",
+	       cs_loader);
 	return 0;
 }
 
@@ -120,11 +122,12 @@ __setup("CS_trigger=", cs_trigger_setup);
  * invoke /sbin/caitsith-init and wait for the termination of
  * /sbin/caitsith-init and then continues invocation of /sbin/init.
  * /sbin/caitsith-init reads policy files in /etc/caitsith/ directory and
- * writes to /proc/caitsith/ interfaces.
+ * writes to /sys/kernel/security/caitsith/ interfaces.
  */
 static void cs_load_policy(const char *filename)
 {
 	static _Bool done;
+
 	if (caitsith_ops.disabled || done)
 		return;
 	if (!cs_trigger)
@@ -137,6 +140,7 @@ static void cs_load_policy(const char *filename)
 	{
 		char *argv[2];
 		char *envp[3];
+
 		printk(KERN_INFO "Calling %s to load policy. Please wait.\n",
 		       cs_loader);
 		argv[0] = (char *) cs_loader;
