@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.17   2016/09/28
+ * Version: 0.2   2016/10/05
  */
 
 #include "caitsith.h"
@@ -136,7 +136,6 @@ static int cs_path_number_perm(const enum cs_mac_index type,
 			       const struct path *path, unsigned long number);
 static int cs_path_perm(const enum cs_mac_index operation,
 			const struct path *path);
-int cs_start_execve(struct linux_binprm *bprm, struct cs_request_info **rp);
 static void cs_check_auto_domain_transition(void);
 static void cs_clear_request_info(struct cs_request_info *r);
 
@@ -185,6 +184,7 @@ static void cs_unescape(unsigned char *dest);
 static inline int cs_copy_argv(const char *arg, struct linux_binprm *bprm)
 {
 	const int ret = copy_strings_kernel(1, &arg, bprm);
+
 	if (ret >= 0)
 		bprm->argc++;
 	return ret;
@@ -203,6 +203,7 @@ static inline int cs_copy_argv(const char *arg, struct linux_binprm *bprm)
 static inline int cs_copy_argv(char *arg, struct linux_binprm *bprm)
 {
 	const int ret = copy_strings_kernel(1, &arg, bprm);
+
 	if (ret >= 0)
 		bprm->argc++;
 	return ret;
@@ -276,6 +277,7 @@ static bool cs_path_matches_group(const struct cs_path_info *pathname,
 				  const struct cs_group *group)
 {
 	struct cs_string_group *member;
+
 	list_for_each_entry_srcu(member, &group->member_list, head.list,
 				 &cs_ss) {
 		if (member->head.is_deleted)
@@ -304,6 +306,7 @@ static bool cs_number_matches_group(const unsigned long min,
 {
 	struct cs_number_group *member;
 	bool matched = false;
+
 	list_for_each_entry_srcu(member, &group->member_list, head.list,
 				 &cs_ss) {
 		if (member->head.is_deleted)
@@ -346,6 +349,7 @@ static int cs_check_acl_list(struct cs_request_info *r)
 	struct cs_acl_info *ptr;
 	int error = 0;
 	struct list_head * const list = &cs_acl_list[r->type];
+
 	r->matched_acl = NULL;
 	list_for_each_entry_srcu(ptr, list, list, &cs_ss) {
 		struct cs_acl_info *ptr2;
@@ -402,8 +406,7 @@ oom:
 
 		if (oom != cs_last_oom) {
 			cs_last_oom = oom;
-			printk(KERN_INFO "CaitSith: Rejecting access "
-			       "request due to out of memory.\n");
+			printk(KERN_INFO "CaitSith: Rejecting access request due to out of memory.\n");
 		}
 	}
 	return -ENOMEM;
@@ -421,6 +424,7 @@ int cs_check_acl(struct cs_request_info *r, const bool clear)
 {
 	int error;
 	const int idx = cs_read_lock();
+
 	error = cs_check_acl_list(r);
 	cs_read_unlock(idx);
 	if (clear)
@@ -506,6 +510,7 @@ static void cs_unescape(unsigned char *dest)
 	unsigned char c;
 	unsigned char d;
 	unsigned char e;
+
 	while (1) {
 		c = *src++;
 		if (!c)
@@ -630,9 +635,9 @@ static int cs_try_alt_exec(struct cs_request_info *r)
 		 * order to decide whether to execve() or not (rather than by
 		 * auditing daemon in init's user namespace).
 		 */
- 		snprintf(r->tmp, CS_EXEC_TMPSIZE - 1,
-			 "pid=%d uid=%d gid=%d euid=%d egid=%d suid=%d "
-			 "sgid=%d fsuid=%d fsgid=%d", cs_sys_getpid(),
+		snprintf(r->tmp, CS_EXEC_TMPSIZE - 1,
+			 "pid=%d uid=%d gid=%d euid=%d egid=%d suid=%d sgid=%d fsuid=%d fsgid=%d",
+			 cs_sys_getpid(),
 			 __kuid_val(current_uid()), __kgid_val(current_gid()),
 			 __kuid_val(current_euid()),
 			 __kgid_val(current_egid()),
@@ -642,8 +647,8 @@ static int cs_try_alt_exec(struct cs_request_info *r)
 			 __kgid_val(current_fsgid()));
 #else
 		snprintf(r->tmp, CS_EXEC_TMPSIZE - 1,
-			 "pid=%d uid=%d gid=%d euid=%d egid=%d suid=%d "
-			 "sgid=%d fsuid=%d fsgid=%d", cs_sys_getpid(),
+			 "pid=%d uid=%d gid=%d euid=%d egid=%d suid=%d sgid=%d fsuid=%d fsgid=%d",
+			 cs_sys_getpid(),
 			 current_uid(), current_gid(), current_euid(),
 			 current_egid(), current_suid(), current_sgid(),
 			 current_fsuid(), current_fsgid());
@@ -656,6 +661,7 @@ static int cs_try_alt_exec(struct cs_request_info *r)
 	/* Set argv[2] */
 	{
 		char *exe = cs_get_exe();
+
 		if (exe) {
 			retval = cs_copy_argv(exe, bprm);
 			kfree(exe);
@@ -686,6 +692,7 @@ static int cs_try_alt_exec(struct cs_request_info *r)
 		char *cp;
 		int root_len;
 		int handler_len;
+
 		get_fs_root(current->fs, &root);
 		cp = cs_realpath(&root);
 		path_put(&root);
@@ -741,6 +748,7 @@ static int cs_try_alt_exec(struct cs_request_info *r)
 	else if (cs_pathcmp(r->param.s[0], r->handler_path)) {
 		/* Failed to verify execute handler. */
 		static u8 counter = 20;
+
 		if (counter) {
 			counter--;
 			printk(KERN_WARNING "Failed to verify: %s\n",
@@ -875,6 +883,7 @@ int cs_start_execve(struct linux_binprm *bprm, struct cs_request_info **rp)
 void cs_finish_execve(int retval, struct cs_request_info *r)
 {
 	struct cs_security *task;
+
 	if (!r)
 		return;
 	task = cs_current_security();
@@ -916,6 +925,7 @@ static int cs_kern_path(const char *pathname, int flags, struct path *path)
 		return -ENOENT;
 #else
 	struct nameidata nd;
+
 	if (!pathname || path_lookup(pathname, flags, &nd))
 		return -ENOENT;
 	*path = nd.path;
@@ -987,6 +997,7 @@ static int cs_mount_acl(const char *dev_name, const struct path *dir,
 	} else {
 		/* do_new_mount() case. */
 		struct file_system_type *fstype;
+
 		if (!type)
 			return -EINVAL;
 		fstype = get_fs_type(type);
@@ -1160,6 +1171,7 @@ static int cs_path_perm(const enum cs_mac_index operation,
 			const struct path *path)
 {
 	struct cs_request_info r = { };
+
 	cs_check_auto_domain_transition();
 	r.type = operation;
 	r.obj.path[0] = *path;
@@ -1180,6 +1192,7 @@ static int cs_mkdev_perm(const u8 operation, const struct path *path,
 			 const unsigned int mode, unsigned int dev)
 {
 	struct cs_request_info r = { };
+
 	cs_check_auto_domain_transition();
 	r.obj.path[0] = *path;
 #ifdef CONFIG_SECURITY_PATH
@@ -1205,6 +1218,7 @@ static int cs_path2_perm(const enum cs_mac_index operation,
 			 const struct path *path1, const struct path *path2)
 {
 	struct cs_request_info r = { };
+
 	cs_check_auto_domain_transition();
 	r.type = operation;
 	r.obj.path[0] = *path1;
@@ -1223,6 +1237,7 @@ static int cs_path2_perm(const enum cs_mac_index operation,
 int cs_symlink_permission(const struct path *path, const char *target)
 {
 	struct cs_request_info r = { };
+
 	cs_check_auto_domain_transition();
 	r.type = CS_MAC_SYMLINK;
 	r.obj.path[0] = *path;
@@ -1247,6 +1262,7 @@ static int cs_path_number_perm(const enum cs_mac_index type,
 			       const struct path *path, unsigned long number)
 {
 	struct cs_request_info r = { };
+
 	cs_check_auto_domain_transition();
 	r.type = type;
 	r.obj.path[0] = *path;
@@ -1296,6 +1312,7 @@ int cs_chmod_permission(const struct path *path, mode_t mode)
 int cs_chown_permission(const struct path *path, kuid_t user, kgid_t group)
 {
 	int error = 0;
+
 	if (uid_valid(user))
 		error = cs_path_number_perm(CS_MAC_CHOWN, path,
 					    from_kuid(&init_user_ns, user));
@@ -1319,6 +1336,7 @@ int cs_chown_permission(const struct path *path, kuid_t user, kgid_t group)
 int cs_chown_permission(const struct path *path, uid_t user, gid_t group)
 {
 	int error = 0;
+
 	if (user == (uid_t) -1 && group == (gid_t) -1)
 		return 0;
 	if (user != (uid_t) -1)
@@ -1407,6 +1425,7 @@ int cs_mknod_permission(const struct path *path, const unsigned int mode,
 {
 	int error = 0;
 	const unsigned int perm = mode & S_IALLUGO;
+
 	switch (mode & S_IFMT) {
 	case S_IFCHR:
 		error = cs_mkdev_perm(CS_MAC_MKCHAR, path, perm, dev);
@@ -1533,6 +1552,7 @@ int cs_sysctl_permission(enum cs_mac_index type,
 			 const struct cs_path_info *filename)
 {
 	struct cs_request_info r = { };
+
 	r.type = type;
 	r.param.s[0] = filename;
 	cs_check_auto_domain_transition();
@@ -1560,6 +1580,7 @@ static bool cs_ip_matches_group(const bool is_ipv6, const u8 *address,
 	struct cs_ip_group *member;
 	bool matched = false;
 	const u8 size = is_ipv6 ? 16 : 4;
+
 	list_for_each_entry_srcu(member, &group->member_list, head.list,
 				 &cs_ss) {
 		if (member->head.is_deleted)
@@ -1585,6 +1606,7 @@ static bool cs_ip_matches_group(const bool is_ipv6, const u8 *address,
 static int cs_inet_entry(const struct cs_addr_info *address)
 {
 	struct cs_request_info r = { };
+
 	cs_check_auto_domain_transition();
 	r.type = address->operation;
 	r.param.is_ipv6 = address->inet.is_ipv6;
@@ -1608,6 +1630,7 @@ static int cs_check_inet_address(const struct sockaddr *addr,
 				 struct cs_addr_info *address)
 {
 	struct cs_inet_addr_info *i = &address->inet;
+
 	switch (addr->sa_family) {
 	case AF_INET6:
 		if (addr_len < SIN6_LEN_RFC2133)
@@ -1647,6 +1670,7 @@ static int cs_unix_entry(const struct cs_addr_info *address)
 	int error;
 	char *buf = address->unix0.addr;
 	int len = address->unix0.addr_len - sizeof(sa_family_t);
+
 	if (len <= 0) {
 		buf = "anonymous";
 		len = 9;
@@ -1657,6 +1681,7 @@ static int cs_unix_entry(const struct cs_addr_info *address)
 	if (buf) {
 		struct cs_path_info addr;
 		struct cs_request_info r = { };
+
 		addr.name = buf;
 		cs_fill_path_info(&addr);
 		r.type = address->operation;
@@ -1682,6 +1707,7 @@ static int cs_check_unix_address(struct sockaddr *addr,
 				 struct cs_addr_info *address)
 {
 	struct cs_unix_addr_info *u = &address->unix0;
+
 	if (addr->sa_family != AF_UNIX)
 		return 0;
 	u->addr = ((struct sockaddr_un *) addr)->sun_path;
@@ -1699,6 +1725,7 @@ static int cs_check_unix_address(struct sockaddr *addr,
 static u8 cs_sock_family(struct sock *sk)
 {
 	u8 family;
+
 	if (cs_kernel_service())
 		return 0;
 	family = sk->sk_family;
@@ -1726,6 +1753,7 @@ int cs_socket_listen_permission(struct socket *sock)
 	const unsigned int type = sock->type;
 	struct sockaddr_storage addr;
 	int addr_len;
+
 	if (!family || (type != SOCK_STREAM && type != SOCK_SEQPACKET))
 		return 0;
 	{
@@ -1761,6 +1789,7 @@ int cs_socket_connect_permission(struct socket *sock, struct sockaddr *addr,
 {
 	struct cs_addr_info address;
 	const u8 family = cs_sock_family(sock->sk);
+
 	if (!family)
 		return 0;
 	switch (sock->type) {
@@ -1804,6 +1833,7 @@ int cs_socket_bind_permission(struct socket *sock, struct sockaddr *addr,
 	struct cs_addr_info address;
 	const u8 family = cs_sock_family(sock->sk);
 	const unsigned int type = sock->type;
+
 	if (!family)
 		return 0;
 	switch (type) {
@@ -1847,6 +1877,7 @@ int cs_socket_sendmsg_permission(struct socket *sock, struct msghdr *msg,
 	struct cs_addr_info address;
 	const u8 family = cs_sock_family(sock->sk);
 	const unsigned int type = sock->type;
+
 	if (!msg->msg_name || !family ||
 	    (type != SOCK_DGRAM && type != SOCK_RAW))
 		return 0;
@@ -1881,6 +1912,7 @@ int cs_socket_post_accept_permission(struct socket *sock,
 	const unsigned int type = sock->type;
 	struct sockaddr_storage addr;
 	int addr_len;
+
 	if (!family || (type != SOCK_STREAM && type != SOCK_SEQPACKET))
 		return 0;
 	{
@@ -1932,6 +1964,7 @@ static bool cs_kernel_service(void)
 bool cs_capable(const u8 operation)
 {
 	struct cs_request_info r = { };
+
 	r.type = cs_c2mac[operation];
 	return !cs_check_acl(&r, true);
 }
@@ -1962,13 +1995,14 @@ int cs_socket_create_permission(int family, int type, int protocol)
  * cs_manager - Check whether the current process is a policy manager.
  *
  * Returns true if the current process is permitted to modify policy
- * via /proc/caitsith/ interface.
+ * via /sys/kernel/security/caitsith/ interface.
  *
  * Caller holds cs_read_lock().
  */
 bool cs_manager(void)
 {
 	struct cs_security *task;
+
 	if (!cs_policy_loaded)
 		return true;
 	task = cs_current_security();
@@ -1976,6 +2010,7 @@ bool cs_manager(void)
 		return true;
 	{
 		struct cs_request_info r = { };
+
 		r.type = CS_MAC_MODIFY_POLICY;
 		if (cs_check_acl(&r, true) == 0) {
 			/* Set manager flag. */
@@ -1986,10 +2021,12 @@ bool cs_manager(void)
 	{ /* Reduce error messages. */
 		static pid_t cs_last_pid;
 		const pid_t pid = current->pid;
+
 		if (cs_last_pid != pid) {
 			const char *exe = cs_get_exe();
-			printk(KERN_WARNING "'%s' (pid=%u domain='%s') is"
-			       " not permitted to update policies.\n", exe,
+
+			printk(KERN_WARNING "'%s' (pid=%u domain='%s') is not permitted to update policies.\n",
+			       exe,
 			       pid, task->cs_domain_info->domainname->name);
 			cs_last_pid = pid;
 			kfree(exe);
@@ -2014,6 +2051,7 @@ static int cs_env_perm(struct cs_request_info *r, const char *name,
 {
 	struct cs_path_info n;
 	struct cs_path_info v;
+
 	n.name = name;
 	cs_fill_path_info(&n);
 	v.name = value;
@@ -2043,6 +2081,7 @@ static int cs_environ(struct cs_request_info *r)
 	int argv_count = bprm->argc;
 	int envp_count = bprm->envc;
 	int error = -ENOMEM;
+
 	arg_ptr = kzalloc(CS_EXEC_TMPSIZE, GFP_NOFS);
 	if (!arg_ptr) {
 		r->failed_by_oom = true;
@@ -2066,6 +2105,7 @@ static int cs_environ(struct cs_request_info *r)
 		while (offset < PAGE_SIZE) {
 			char *value;
 			const unsigned char c = env_page.data[offset++];
+
 			if (c && arg_len < CS_EXEC_TMPSIZE - 10) {
 				if (c > ' ' && c < 127 && c != '\\') {
 					arg_ptr[arg_len++] = c;
@@ -2151,6 +2191,7 @@ static bool cs_check_argv(struct cs_request_info *r, unsigned long index,
 	unsigned long pos = bprm->p;
 	int offset = pos % PAGE_SIZE;
 	struct cs_path_info arg;
+
 	if (index > bprm->argc)
 		return false;
 	while (1) {
@@ -2161,6 +2202,7 @@ static bool cs_check_argv(struct cs_request_info *r, unsigned long index,
 		pos += PAGE_SIZE - offset;
 		while (offset < PAGE_SIZE) {
 			const unsigned char c = dump->data[offset++];
+
 			if (index) {
 				if (!c)
 					index--;
@@ -2216,6 +2258,7 @@ static bool cs_check_envp(struct cs_request_info *r,
 	bool result = false;
 	struct cs_path_info env;
 	char *cp;
+
 	while (envp_count) {
 		if (!cs_dump_page(bprm, pos, dump)) {
 			r->failed_by_oom = true;
@@ -2224,6 +2267,7 @@ static bool cs_check_envp(struct cs_request_info *r,
 		pos += PAGE_SIZE - offset;
 		while (envp_count && offset < PAGE_SIZE) {
 			const unsigned char c = dump->data[offset++];
+
 			if (argv_count) {
 				if (!c)
 					argv_count--;
@@ -2328,6 +2372,7 @@ void cs_get_attributes(struct cs_request_info *r)
 		return;
 	for (i = 0; i < CS_MAX_PATH_STAT; i++) {
 		struct inode *inode;
+
 		switch (i) {
 		case CS_PATH1:
 			dentry = r->obj.path[0].dentry;
@@ -2348,6 +2393,7 @@ void cs_get_attributes(struct cs_request_info *r)
 		inode = d_backing_inode(dentry);
 		if (inode) {
 			struct cs_mini_stat *stat = &r->obj.stat[i];
+
 			stat->uid  = inode->i_uid;
 			stat->gid  = inode->i_gid;
 			stat->ino  = inode->i_ino;
@@ -2375,6 +2421,7 @@ void cs_populate_patharg(struct cs_request_info *r, const bool first)
 {
 	struct cs_path_info *buf = &r->obj.pathname[!first];
 	struct path *path = &r->obj.path[!first];
+
 	if (!buf->name && path->dentry) {
 		buf->name = cs_realpath(path);
 		/* Set OOM flag if failed. */
@@ -2411,6 +2458,7 @@ static bool cs_cond2arg(struct cs_cond_arg *arg,
 	unsigned long value;
 	const struct linux_binprm *bprm = r->bprm;
 	const struct cs_request_param *param = &r->param;
+
 	arg->type = CS_ARG_TYPE_NUMBER;
 	switch (cmd) {
 	case CS_SELF_UID:
@@ -2709,6 +2757,7 @@ static bool cs_condition(struct cs_request_info *r,
 			 const struct cs_condition *cond)
 {
 	const union cs_condition_element *condp;
+
 	if (!cond)
 		return true;
 	condp = (typeof(condp)) (cond + 1);
@@ -2718,6 +2767,7 @@ static bool cs_condition(struct cs_request_info *r,
 		const enum cs_conditions_index left_op = condp->left;
 		const enum cs_conditions_index right_op = condp->right;
 		const bool match = !condp->is_not;
+
 		condp++;
 		if (!cs_cond2arg(&left, left_op, &condp, r) ||
 		    !cs_cond2arg(&right, right_op, &condp, r))
@@ -2834,6 +2884,7 @@ static void cs_check_auto_domain_transition(void)
 #ifdef CONFIG_CAITSITH_AUTO_DOMAIN_TRANSITION
 	struct cs_request_info r = { };
 	const int idx = cs_read_lock();
+
 	r.type = CS_MAC_AUTO_DOMAIN_TRANSITION;
 	cs_check_acl(&r, true);
 	if (r.result != CS_MATCHING_ALLOWED ||
@@ -2890,6 +2941,7 @@ static bool cs_file_matches_pattern2(const char *filename,
 {
 	while (filename < filename_end && pattern < pattern_end) {
 		char c;
+
 		if (*pattern != '\\') {
 			if (*filename++ != *pattern++)
 				return false;
@@ -3002,6 +3054,7 @@ static bool cs_file_matches_pattern(const char *filename,
 	const char *pattern_start = pattern;
 	bool first = true;
 	bool result;
+
 	while (pattern < pattern_end - 1) {
 		/* Split at "\-" pattern. */
 		if (*pattern++ != '\\' || *pattern++ != '-')
@@ -3032,6 +3085,7 @@ static bool cs_path_matches_pattern2(const char *f, const char *p)
 {
 	const char *f_delimiter;
 	const char *p_delimiter;
+
 	while (*f && *p) {
 		f_delimiter = strchr(f + 1, '/');
 		if (!f_delimiter)
